##############################
#Intro to Duration Workshop
#September 25, 2013
#StatLab@UVa Library
#Michele Claibourn
##############################

#Read example 1: Cabinet duration
library(foreign)
coal <- read.dta('~/workshops/duration_models/coalum.dta')

#Set up data as survival
library(survival)
attach(coal)
coal.s <- Surv(durat, censor12)~1

##Nonparametric estimation
#KM survivor function
coal.surv <- survfit(coal.s)
summary(coal.surv)
plot(coal.surv, xlab="Months", ylab="Survival Probability")

#Cumulative hazard function
#No existing function in survival library, but can be created in multiple ways
#E.g., get Nelson-Aalen estimator via cox regression using coxph function
na <- survfit(coxph(Surv(durat,censor12)~1), type="aalen")
summary(na)

h.na <- (-log(na$surv))
na.est<-data.frame(cbind(time=na$time, d=na$n.event, n=na$n.risk, 
                 h.na, s1=na$surv))

plot(na.est$time, na.est$h.na, type="s", xlab="Survival Time", 
     ylab="Cumulative Hazard")

#Hazard function
#No existing function in survival library, but can be created from prior results
h2<-na.est$d/na.est$n
plot(na.est$time, h2, type="p", pch=20, xlab="Survival Time (Months)", 
     ylab="Hazard Ratio")
lines(lowess(na.est$time, h2,f=.75, iter=5))

#Bivariate survival/hazard
coal.s2 <- Surv(durat, censor12)~majority
coal.surv2 <- survfit(coal.s2)
plot(coal.surv2, xlab="Months", ylab="Survival Probability")

#Log-rank test of difference in survival
survdiff(Surv(durat, censor12)~majority, rho=0)

detach(coal)

##Cox proportional hazard model
#Read example 2: Recidivism
rossi <- read.table('J:/public_html/IntroDuration/Rossi.txt', header=TRUE)
attach(rossi)
rossi.s <- Surv(week, arrest)~1
#KM survivor function
rossi.surv <- survfit(rossi.s)
plot(rossi.surv, xlab="Weeks", ylab="Survival Probability")

#Cox PH models, uses Efron method for ties by default
rec.1 <- coxph(Surv(week, arrest) ~ fin + age + race + wexp + 
  mar + paro + prio, data=Rossi)
summary(rec.1)

#Exact partial likelihood method for ties
rec.2 <- coxph(Surv(week, arrest) ~ fin + age + race + wexp + 
                 mar + paro + prio, ties="exact", data=Rossi)
summary(rec.2)

#Graph the basline survivor function
rec1.surv <- survfit(rec.1)
plot(rec1.surv, xlab="Weeks", ylab="Survival Probability")

#Graph the baseline hazard function
rec.1na <- survfit(rec.1, type="aalen")
rec.1h <- (-log(rec.1na$surv))
rec.1h.est<-data.frame(cbind(time=rec.1na$time, d=rec.1na$n.event, n=rec.1na$n.risk, 
  rec.1h, s1=rec.1na$surv))
rec1.bh <- rec.1h.est$d/rec.1h.est$n
plot(rec.1h.est$time, rec1.bh, type="p", pch=20, xlab="Survival Time (Months)", 
     ylab="Hazard Ratio")
lines(lowess(rec.1h.est$time, rec1.bh, f=.75, iter=5))

detach(rossi)

#Read example 3: AIDS clinical trials group
act <- read.table('J:/public_html/IntroDuration/actg320.dat', 
  col.names=c('id', 'time', 'censor', 'time_d', 'censor_d', 'tx', 
              'txgrp', 'strat2', 'sex', 'raceth', 'ivdrug', 
              'hemophil', 'karnof', 'cd4', 'priorzdv', 'age'))
head(act)

#KM estimate
attach(act)
act.s <- Surv(time, censor)~1
act.surv <- survfit(act.s)
plot(act.surv, xlab="Days", ylab="Survival Probability")

#Plot by treatment
act.s2 <- Surv(time, censor)~tx
act.surv2 <- survfit(act.s2)
plot(act.surv2, xlab="Days", ylab="Survival Probability")

#Cox model
act.1 <- coxph(Surv(time, censor) ~ tx, data=act)
summary(act.1)

act.2 <- coxph(Surv(time, censor) ~ tx + age + sex + cd4 + priorzdv, data=act)
summary(act.2)
