*******************************
*Intro to Duration 
*September 25, 2013
*StatLab@UVa Library
*Michele Claibourn
*******************************

**Read in example 1: Cabinet dissolution
cd "C:\Users\jcf2d\Documents\workshops\duration_models"
use "coalum.dta", clear

*To estimate survival models in Stata, we must tell Stata the format of our data
*stset = survival time
stset durat, failure(censor12) /*failure indicates censoring*/
save "coalum2.dta", replace

*Describe the stset data
stdes

*Nonparametric estimation
*List/graph KM survivor function
sts list
sts graph, ci

*List/graph cumulative hazard function
sts list, cumhaz
sts graph, cumhaz

**Graph hazard rate
sts graph, hazard ci

**We could do this by groups to compare (e.g., bivariate)
sts graph, by(majority) 
sts graph, hazard by(majority) ci

*And conduct a test for whether the functions are equal across group
sts test majority, logrank


**Read in example 2: Recidivism 
use "rossi.dta", clear
stset week, failure(arrest)
stdes
sts graph, by(fin) ci

*Cox PH models
stcox fin age race wexp mar paro prio, nohr
stcox fin age race wexp mar paro prio

*Efron method for ties
stcox fin age race wexp mar paro prio, nohr efron

*Exact partial likelihood method for ties
stcox fin age race wexp mar paro prio, nohr exactp

*Graph the baseline survivor function
quietly stcox fin age race wexp mar paro prio, nohr efron basesurv(surv)
graph twoway connected surv week, c(J) /// 
sort msymbol(S) msize(0.08) title("Baseline Survival Function")  ///
xtitle("Recidivism in Weeks") ytitle("Baseline Survival Function")

*Get the baseline integrated hazard function
quietly stcox fin age race wexp mar paro prio, nohr efron basechazard(cumhazard)

*Graph the baseline hazard function
quietly stcox fin age race wexp mar paro prio, nohr efron basehc(baslinehazard)
graph twoway connected baslinehazard week, c(J) /// 
sort msymbol(S) msize(0.08) title("Baseline hazard function") ///
xtitle("Recidivism in Weeks") ytitle("Baseline hazard") 

*Smooth the baseline hazard
lowess baslinehazard week, c(J) ///
sort msymbol(S) msize(0.08) bwidth(0.5) title("Baseline hazard function") ///
xtitle("Recidivism in Weeks") ytitle("Baseline hazard")


**Read in example 1: Cabinet duration
use "J:\public_html\IntroDuration\coalum2.dta", clear

*Cox PH Model: estimate the model and save the baseline hazard
stcox majority volat polar fract crisis format oppcon invest, nohr exactp basehc(baselinehazard)

*Graph the smoothed hazard function
lowess baselinehazard durat, sort msymbol(S) msize(0.08) bwidth(0.5) title("Baseline hazard function") xtitle("Cabinet Duration in months") ytitle("Baseline hazard")


**Read in example 3: AIDS clinical trial
use "act.dta", clear
stset time, failure(censor)
stdes

**Graph survival, hazard
sts graph, ci
sts graph, hazard ci
sts graph, by(tx) ci

**Cox model
stcox tx, nohr efron
stcox tx age sex cd4 priorzdv, nohr efron
